==> borg-1.4.1.tar.gz: lib/src/configuration/options/paths.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

part of '../factory.dart';

void _addPathsMultiOption({
  @required ArgParser argParser,
  @required Iterable<String> defaultsTo,
}) =>
    argParser.addMultiOption(
      _namePathsMultiOption,
      abbr: 'p',
      help: 'list of paths to scan for Dart packages (glob syntax allowed)',
      valueHelp: 'PATH1,PATH2,...',
      defaultsTo: defaultsTo,
    );

// ignore: avoid_as
Iterable<String> _getPathsMultiOption(ArgResults argResults) => argResults[_namePathsMultiOption] as Iterable<String>;

const _namePathsMultiOption = 'paths';

==> borg-1.4.6.tar.gz: lib/src/configuration/options/paths.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

part of '../factory.dart';

void _addPathsMultiOption({
  @required ArgParser argParser,
  @required Iterable<String> defaultsTo,
}) =>
    argParser.addMultiOption(
      _namePathsMultiOption,
      abbr: 'p',
      help: 'list of paths to scan for Dart packages (glob syntax allowed)',
      valueHelp: 'PATH1,PATH2,...',
      defaultsTo: defaultsTo,
    );

// ignore: avoid_as
Iterable<String> _getPathsMultiOption(ArgResults argResults) =>
    // ignore: avoid_as
    argResults[_namePathsMultiOption] as Iterable<String>;

const _namePathsMultiOption = 'paths';
